summaryrefslogtreecommitdiffstats
path: root/twin/kcmtwin/twindecoration
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:46:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:46:05 -0600
commit73c08b592db45af554b9f21029bc549d70f683ab (patch)
tree122898ea951e59fdc4419b3c84b7a6c2dd0bb5f7 /twin/kcmtwin/twindecoration
parente81bdee8ae92d6eeb82daa8c0a0e46bf37f4a6da (diff)
downloadtdebase-73c08b592db45af554b9f21029bc549d70f683ab.tar.gz
tdebase-73c08b592db45af554b9f21029bc549d70f683ab.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'twin/kcmtwin/twindecoration')
-rw-r--r--twin/kcmtwin/twindecoration/buttons.cpp38
-rw-r--r--twin/kcmtwin/twindecoration/buttons.h2
-rw-r--r--twin/kcmtwin/twindecoration/preview.cpp14
-rw-r--r--twin/kcmtwin/twindecoration/twindecoration.cpp10
4 files changed, 32 insertions, 32 deletions
diff --git a/twin/kcmtwin/twindecoration/buttons.h b/twin/kcmtwin/twindecoration/buttons.h
index 088d3414d..e1dbbc812 100644
--- a/twin/kcmtwin/twindecoration/buttons.h
+++ b/twin/kcmtwin/twindecoration/buttons.h
@@ -117,7 +117,7 @@ class ButtonSource : public KListView
ButtonSource(TQWidget *parent = 0, const char* name = 0);
virtual ~ButtonSource();
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
void hideAllButtons();
void showAllButtons();
diff --git a/twin/kcmtwin/twindecoration/preview.cpp b/twin/kcmtwin/twindecoration/preview.cpp
index ee8c59c75..573971f27 100644
--- a/twin/kcmtwin/twindecoration/preview.cpp
+++ b/twin/kcmtwin/twindecoration/preview.cpp
@@ -49,7 +49,7 @@ KDecorationPreview::KDecorationPreview( TQWidget* parent, const char* name )
"Most probably there\n"
"was a problem loading the plugin." ), this );
- no_preview->tqsetAlignment( AlignCenter );
+ no_preview->setAlignment( AlignCenter );
setMinimumSize( 100, 100 );
no_preview->resize( size());
@@ -127,15 +127,15 @@ void KDecorationPreview::positionPreviews()
// Resize the active window
size = TQSize( width() - xoffset, height() - titleBarHeight )
- .expandedTo( deco[Active]->tqminimumSize() );
+ .expandedTo( deco[Active]->minimumSize() );
geometry = TQRect( TQPoint( 0, titleBarHeight ), size );
- deco[Active]->widget()->setGeometry( TQStyle::tqvisualRect( geometry, this ) );
+ deco[Active]->widget()->setGeometry( TQStyle::visualRect( geometry, this ) );
// Resize the inactive window
size = TQSize( width() - xoffset, height() - titleBarHeight )
- .expandedTo( deco[Inactive]->tqminimumSize() );
+ .expandedTo( deco[Inactive]->minimumSize() );
geometry = TQRect( TQPoint( xoffset, 0 ), size );
- deco[Inactive]->widget()->setGeometry( TQStyle::tqvisualRect( geometry, this ) );
+ deco[Inactive]->widget()->setGeometry( TQStyle::visualRect( geometry, this ) );
}
void KDecorationPreview::setPreviewMask( const TQRegion& reg, int mode, bool active )
@@ -150,7 +150,7 @@ void KDecorationPreview::setPreviewMask( const TQRegion& reg, int mode, bool act
}
else
{
- TQMemArray< TQRect > rects = reg.tqrects();
+ TQMemArray< TQRect > rects = reg.rects();
XRectangle* xrects = new XRectangle[ rects.count() ];
for( unsigned int i = 0;
i < rects.count();
@@ -166,7 +166,7 @@ void KDecorationPreview::setPreviewMask( const TQRegion& reg, int mode, bool act
delete[] xrects;
}
if( active )
- mask = reg; // keep tqshape of the active window for unobscuredRegion()
+ mask = reg; // keep shape of the active window for unobscuredRegion()
}
TQRect KDecorationPreview::windowGeometry( bool active ) const
diff --git a/twin/kcmtwin/twindecoration/twindecoration.cpp b/twin/kcmtwin/twindecoration/twindecoration.cpp
index 4ef509e5a..e48f4e234 100644
--- a/twin/kcmtwin/twindecoration/twindecoration.cpp
+++ b/twin/kcmtwin/twindecoration/twindecoration.cpp
@@ -32,7 +32,7 @@
#include <tqdir.h>
#include <tqfileinfo.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqwhatsthis.h>
#include <tqgroupbox.h>
#include <tqcheckbox.h>
@@ -112,13 +112,13 @@ KWinDecorationModule::KWinDecorationModule(TQWidget* parent, const char* name, c
TQWhatsThis::add( cBorder, i18n( "Use this combobox to change the border size of the decoration." ));
lBorder->hide();
cBorder->hide();
- TQHBoxLayout *borderSizeLayout = new TQHBoxLayout(pluginSettingsGrp->tqlayout() );
+ TQHBoxLayout *borderSizeLayout = new TQHBoxLayout(pluginSettingsGrp->layout() );
borderSizeLayout->addWidget(lBorder);
borderSizeLayout->addWidget(cBorder);
borderSizeLayout->addStretch();
pluginConfigWidget = new TQVBox(pluginSettingsGrp);
- pluginSettingsGrp->tqlayout()->add( pluginConfigWidget );
+ pluginSettingsGrp->layout()->add( pluginConfigWidget );
// Page 2 (Button Selector)
TQWidget* buttonPage = new TQWidget( tabWidget );
@@ -154,8 +154,8 @@ KWinDecorationModule::KWinDecorationModule(TQWidget* parent, const char* name, c
preview = new KDecorationPreview( this );
previewLayout->addWidget(preview);
- preview->tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
- tabWidget->tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Maximum);
+ preview->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
+ tabWidget->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Maximum);
// Page 3 (Window Shadows)
TQHBox *inactiveShadowColourHBox, *shadowColourHBox;
diff --git a/twin/kcmtwin/twindecoration/buttons.cpp b/twin/kcmtwin/twindecoration/buttons.cpp
index 2c450aed1..a96ee76de 100644
--- a/twin/kcmtwin/twindecoration/buttons.cpp
+++ b/twin/kcmtwin/twindecoration/buttons.cpp
@@ -31,7 +31,7 @@
#include <tqheader.h>
#include <tqpainter.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqstyle.h>
#include <kdebug.h>
@@ -54,7 +54,7 @@ ButtonDrag::ButtonDrag( Button btn, TQWidget* parent, const char* name)
TQDataStream stream(data, IO_WriteOnly);
stream << btn.name;
stream << btn.icon;
- stream << btn.type.tqunicode();
+ stream << btn.type.unicode();
stream << (int) btn.duplicate;
stream << (int) btn.supported;
setEncodedData( data );
@@ -123,7 +123,7 @@ TQPixmap bitmapPixmap(const TQBitmap& bm, const TQColor& color)
ButtonSource::ButtonSource(TQWidget *parent, const char* name)
: KListView(parent, name)
{
- tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
+ setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
setResizeMode(TQListView::AllColumns);
setDragEnabled(true);
@@ -140,19 +140,19 @@ ButtonSource::~ButtonSource()
{
}
-TQSize ButtonSource::tqsizeHint() const
+TQSize ButtonSource::sizeHint() const
{
// make the tqsizeHint height a bit smaller than the one of TQListView...
if ( cachedSizeHint().isValid() )
return cachedSizeHint();
constPolish();
- TQSize s( header()->tqsizeHint() );
+ TQSize s( header()->sizeHint() );
if ( verticalScrollBar()->isVisible() )
- s.setWidth( s.width() + tqstyle().tqpixelMetric(TQStyle::PM_ScrollBarExtent) );
+ s.setWidth( s.width() + tqstyle().pixelMetric(TQStyle::PM_ScrollBarExtent) );
s += TQSize(frameWidth()*2,frameWidth()*2);
// size hint: 4 lines of text...
@@ -167,7 +167,7 @@ void ButtonSource::hideAllButtons()
{
TQListViewItemIterator it(this);
while (it.current() ) {
- it.current()->tqsetVisible(false);
+ it.current()->setVisible(false);
++it;
}
}
@@ -176,7 +176,7 @@ void ButtonSource::showAllButtons()
{
TQListViewItemIterator it(this);
while (it.current() ) {
- it.current()->tqsetVisible(true);
+ it.current()->setVisible(true);
++it;
}
}
@@ -187,7 +187,7 @@ void ButtonSource::showButton( TQChar btn )
while (it.current() ) {
ButtonSourceItem *item = dynamic_cast<ButtonSourceItem*>(it.current() );
if (item && item->button().type == btn) {
- it.current()->tqsetVisible(true);
+ it.current()->setVisible(true);
return;
}
++it;
@@ -200,7 +200,7 @@ void ButtonSource::hideButton( TQChar btn )
while (it.current() ) {
ButtonSourceItem *item = dynamic_cast<ButtonSourceItem*>(it.current() );
if (item && item->button().type == btn && !item->button().duplicate) {
- it.current()->tqsetVisible(false);
+ it.current()->setVisible(false);
return;
}
++it;
@@ -218,7 +218,7 @@ TQDragObject *ButtonSource::dragObject()
if (i) {
ButtonDrag *bd = new ButtonDrag(i->button(), viewport(), "button_drag");
- bd->setPixmap(bitmapPixmap(i->button().icon, tqcolorGroup().foreground() ));
+ bd->setPixmap(bitmapPixmap(i->button().icon, colorGroup().foreground() ));
return bd;
}
@@ -487,7 +487,7 @@ void ButtonDropSite::mousePressEvent( TQMouseEvent* e )
m_selected = buttonAt(e->pos() );
if (m_selected) {
ButtonDrag *bd = new ButtonDrag(m_selected->button(), this);
- bd->setPixmap(bitmapPixmap(m_selected->button().icon, tqcolorGroup().foreground() ) );
+ bd->setPixmap(bitmapPixmap(m_selected->button().icon, colorGroup().foreground() ) );
bd->dragMove();
}
}
@@ -572,7 +572,7 @@ bool ButtonDropSite::removeSelectedButton()
delete m_selected;
m_selected = 0;
recalcItemGeometry();
- update(); // tqrepaint...
+ update(); // repaint...
}
return succ;
@@ -581,9 +581,9 @@ bool ButtonDropSite::removeSelectedButton()
void ButtonDropSite::drawButtonList(TQPainter *p, const ButtonList& btns, int offset)
{
for (ButtonList::const_iterator it = btns.begin(); it != btns.end(); ++it) {
- TQRect tqitemRect = (*it)->rect;
- if (tqitemRect.isValid() ) {
- (*it)->draw(p, tqcolorGroup(), tqitemRect);
+ TQRect itemRect = (*it)->rect;
+ if (itemRect.isValid() ) {
+ (*it)->draw(p, colorGroup(), itemRect);
}
offset += (*it)->width();
}
@@ -675,11 +675,11 @@ ButtonPositionWidget::ButtonPositionWidget(TQWidget *parent, const char* name)
m_factory(0)
{
TQVBoxLayout *layout = new TQVBoxLayout(this, 0, KDialog::spacingHint() );
- tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Maximum);
+ setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Maximum);
TQLabel* label = new TQLabel( this );
m_dropSite = new ButtonDropSite( this );
- label->tqsetAlignment( int( TQLabel::WordBreak ) );
+ label->setAlignment( int( TQLabel::WordBreak ) );
label->setText( i18n( "To add or remove titlebar buttons, simply <i>drag</i> items "
"between the available item list and the titlebar preview. Similarly, "
"drag items within the titlebar preview to re-position them.") );
@@ -140,19 +140,19 @@ ButtonSource::~ButtonSource()
{
- // make the tqsizeHint height a bit smaller than the one of TQListView...
+ // make the sizeHint height a bit smaller than the one of TQListView...
if ( cachedSizeHint().isValid() )
return cachedSizeHint();